"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const filesize_1 = require("filesize");
const useSize_1 = __importDefault(require("./useSize"));
const Styles = __importStar(require("./style"));
const Tooltip_1 = __importDefault(require("../../Tooltip"));
const SvgFromUrl_1 = __importDefault(require("../../SvgFromUrl"));
function VideoAttachment(props) {
    var _a, _b;
    const [hasPlayedOnceBefore, setHasPlayedOnceBefore] = (0, react_1.useState)(false);
    const [paused, setPaused] = (0, react_1.useState)(true);
    const [showPlayOrPauseAnimation, setShowPlayOrPauseAnimation] = (0, react_1.useState)(false);
    const [durationPlayed, setDurationPlayed] = (0, react_1.useState)(0);
    const [isFullscreen, setIsFullscreen] = (0, react_1.useState)(false);
    const [isSeeking, setIsSeeking] = (0, react_1.useState)(false);
    const videoRef = (0, react_1.useRef)(null);
    const attachmentRef = (0, react_1.useRef)(null);
    const durationPlayedHumanized = (0, react_1.useMemo)(() => {
        var _a, _b, _c, _d;
        const minutesPassed = Math.floor(((_a = videoRef.current) === null || _a === void 0 ? void 0 : _a.currentTime) / 60);
        const secondsPassedRaw = Math.floor(((_b = videoRef.current) === null || _b === void 0 ? void 0 : _b.currentTime) % 60);
        const secondsPassed = secondsPassedRaw < 10 ? `0${secondsPassedRaw}` : secondsPassedRaw;
        const minutesTotal = Math.floor(((_c = videoRef.current) === null || _c === void 0 ? void 0 : _c.duration) / 60);
        const secondsTotalRaw = Math.floor(((_d = videoRef.current) === null || _d === void 0 ? void 0 : _d.duration) % 60);
        const secondsTotal = secondsTotalRaw < 10 ? `0${secondsTotalRaw}` : secondsTotalRaw;
        return `${minutesPassed}:${secondsPassed}/${minutesTotal}:${secondsTotal}`;
    }, [durationPlayed, videoRef.current]);
    function playVideo() {
        const video = videoRef.current;
        if (video === null)
            return;
        if (video.paused)
            video.play();
        else
            video.pause();
    }
    const updatePauseState = (0, react_1.useCallback)((pauseState) => {
        setPaused(pauseState);
        setShowPlayOrPauseAnimation(true);
        setTimeout(() => setShowPlayOrPauseAnimation(false), Styles.PlayOrPauseAnimationDuration);
    }, []);
    const { width: extractedWidth, height: extractedHeight } = "video" in props.attachmentOrEmbed
        ? props.attachmentOrEmbed.video
        : props.attachmentOrEmbed;
    const { width, height } = (0, useSize_1.default)(extractedWidth, extractedHeight, isFullscreen);
    function fullScreenChange() {
        setIsFullscreen(document.fullscreenElement !== null);
    }
    function seekVideo(e, overrideSeeking) {
        var _a;
        if (videoRef.current === null || (!isSeeking && !overrideSeeking))
            return;
        const rect = e.target.getBoundingClientRect();
        const x = e.clientX - rect.left;
        const duration = (_a = videoRef.current) === null || _a === void 0 ? void 0 : _a.duration;
        if (duration === undefined)
            return;
        videoRef.current.currentTime = (x / rect.width) * duration;
    }
    (0, react_1.useEffect)(() => {
        document.addEventListener("fullscreenchange", fullScreenChange);
        return () => {
            document.removeEventListener("fullscreenchange", fullScreenChange);
        };
    }, []);
    return (react_1.default.createElement(Styles.VideoAttachmentContainer, { style: { width, height }, ref: attachmentRef },
        react_1.default.createElement(Styles.VideoAttachment, { preload: "metadata", src: props.attachmentOrEmbed.url, height: height, width: width, ref: videoRef, onPause: () => updatePauseState(true), onPlay: () => {
                updatePauseState(false);
                setHasPlayedOnceBefore(true);
            }, onTimeUpdate: ({ timeStamp }) => setDurationPlayed(timeStamp) }),
        react_1.default.createElement(Styles.VideoAttachmentOverlay, { "data-paused": paused, "data-played-once": hasPlayedOnceBefore },
            (showPlayOrPauseAnimation || !hasPlayedOnceBefore) && (react_1.default.createElement(Styles.PlayOrPauseButtonAnimation, { "data-paused": paused, "data-has-played-before": hasPlayedOnceBefore },
                react_1.default.createElement(SvgFromUrl_1.default, { width: 12, height: 12, svg: paused ? "IconPlay" : "IconPause" }))),
            "filename" in props.attachmentOrEmbed && (react_1.default.createElement(Styles.VideoMetadata, null,
                react_1.default.createElement(Styles.VideoMetadataTitle, null, props.attachmentOrEmbed.filename),
                react_1.default.createElement(Styles.VideoMetadataFilesize, null, (0, filesize_1.filesize)(props.attachmentOrEmbed.size, { base: 2 })))),
            react_1.default.createElement(Styles.VideoAttachmentOverlayControl, { onClick: playVideo }),
            react_1.default.createElement(Styles.VideoControls, null,
                react_1.default.createElement(Styles.VideoControlButton, { width: 14, height: 14, svg: paused ? "IconPlay" : "IconPause", onClick: playVideo }),
                width > 200 && (react_1.default.createElement(Styles.VideoControlsTime, null, durationPlayedHumanized)),
                react_1.default.createElement(Styles.ProgressBar, { onMouseMove: seekVideo, onClick: (e) => seekVideo(e, true), onMouseDown: () => setIsSeeking(true), onMouseUp: () => setIsSeeking(false) },
                    react_1.default.createElement(Styles.ProgressBarFill, { style: {
                            width: (((_a = videoRef.current) === null || _a === void 0 ? void 0 : _a.currentTime) / ((_b = videoRef.current) === null || _b === void 0 ? void 0 : _b.duration)) *
                                100 +
                                "%",
                        } })),
                react_1.default.createElement(Tooltip_1.default, { placement: "top", overlay: "Full Screen" },
                    react_1.default.createElement(Styles.VideoControlButton, { width: 14, height: 14, svg: "IconFullscreen", onClick: () => {
                            var _a;
                            if (document.fullscreenElement === null)
                                (_a = attachmentRef.current) === null || _a === void 0 ? void 0 : _a.requestFullscreen();
                            else
                                void document.exitFullscreen();
                        } }))))));
}
exports.default = VideoAttachment;
//# sourceMappingURL=VideoAttachment.js.map