"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoleIcon = exports.SlashCommandText = exports.UnknownReplyIcon = exports.UnknownReply = exports.SlashCommand = exports.SystemMessageLink = exports.SystemMessageContent = exports.ThreadCreatedIcon = exports.SystemMessageIcon = exports.SystemMessageIconSize = exports.SystemMessage = exports.MiniUserName = exports.MiniUserAvatar = exports.ThreadSpine = exports.ReplySpine = exports.ReplyUser = exports.ReplyInfo = exports.MessageContainerStyle = exports.MessageHeaderBase = exports.Message = exports.LargeTimestamp = exports.SmallTimestamp = void 0;
const stitches_config_1 = require("../../Stitches/stitches.config");
const elements_1 = require("../../markdown/render/elements");
const SvgFromUrl_1 = __importDefault(require("../../SvgFromUrl"));
exports.SmallTimestamp = stitches_config_1.styled.withConfig({
    displayName: "small-timestamp",
    componentId: stitches_config_1.commonComponentId,
})("time", {
    position: "absolute",
    left: 0,
    width: 56,
    textAlign: "right",
    fontSize: stitches_config_1.theme.fontSizes.s,
    marginTop: stitches_config_1.theme.space.small,
    userSelect: "none",
    color: stitches_config_1.theme.colors.primaryOpacity50,
});
exports.LargeTimestamp = stitches_config_1.styled.withConfig({
    displayName: "large-timestamp",
    componentId: stitches_config_1.commonComponentId,
})("time", {
    fontSize: stitches_config_1.theme.fontSizes.s,
    marginLeft: stitches_config_1.theme.space.large,
    cursor: "default",
    height: "fit-content",
    whiteSpace: "nowrap",
    color: stitches_config_1.theme.colors.primaryOpacity50,
    lineHeight: `1.375rem`,
});
exports.Message = stitches_config_1.styled.withConfig({
    displayName: "message",
    componentId: stitches_config_1.commonComponentId,
})("div", {
    position: "relative",
    padding: `2px 48px 2px ${stitches_config_1.theme.sizes.messageLeftPadding}`,
    [`& ${elements_1.Link}`]: {
        color: stitches_config_1.theme.colors.link,
        textDecoration: "none",
        "&:hover": {
            textDecoration: "underline",
        },
    },
    [`${exports.SmallTimestamp}`]: {
        display: "none",
    },
    [`&:hover ${exports.SmallTimestamp}`]: {
        display: "inherit",
    },
    // IF THERE IS A BUG WITH THE HOVER COLOR IT'S BECAUSE WE MOVED THIS
    // FROM THE CONTAINER TO HERE
    "&:hover": {
        backgroundColor: stitches_config_1.theme.colors.messageHover,
    },
    variants: {
        mentioned: {
            true: {
                backgroundColor: stitches_config_1.theme.colors.mentioned,
                "&:hover": {
                    backgroundColor: stitches_config_1.theme.colors.mentionedHover,
                },
                "&:before": {
                    content: "",
                    position: "absolute",
                    left: 0,
                    top: 0,
                    width: 2,
                    height: "100%",
                    backgroundColor: stitches_config_1.theme.colors.mentionedBorder,
                },
            },
        },
    },
});
exports.MessageHeaderBase = stitches_config_1.styled.withConfig({
    displayName: "message-header",
    componentId: stitches_config_1.commonComponentId,
})("div", {
    display: "flex",
    flexDirection: "row",
    alignItems: "center",
});
var MessageContainerStyle;
(function (MessageContainerStyle) {
    MessageContainerStyle.Buttons = stitches_config_1.styled.withConfig({
        displayName: "message-hover-buttons",
        componentId: stitches_config_1.commonComponentId,
    })("div", {
        position: "absolute",
        right: 14,
        top: 0,
        transform: "translateY(-50%)",
        display: "none",
        flexDirection: "row",
        boxShadow: "0 0 0 1px rgba(4, 4, 5, 0.15)",
        backgroundColor: stitches_config_1.theme.colors.background,
        zIndex: 1,
        borderRadius: 4,
        overflow: "hidden",
        transition: "box-shadow 0.1s ease-in-out",
        "&:hover": {
            cursor: "pointer",
            boxShadow: "0 0 0 1px rgba(4, 4, 5, 0.15), 0 4px 4px rgba(0, 0, 0, 0.16)",
        },
    });
    MessageContainerStyle.Button = stitches_config_1.styled.withConfig({
        displayName: "message-hover-button",
        componentId: stitches_config_1.commonComponentId,
    })("button", {
        border: "none",
        display: "flex",
        padding: stitches_config_1.theme.space.medium,
        opacity: 0.7,
        backgroundColor: "transparent",
        "&:hover": {
            backgroundColor: stitches_config_1.theme.colors.primaryOpacity10,
            opacity: 1,
        },
    });
    MessageContainerStyle.MessageContainer = stitches_config_1.styled.withConfig({
        displayName: "message-container",
        componentId: stitches_config_1.commonComponentId,
    })("div", {
        position: "relative",
        "&:hover": {
            [`${MessageContainerStyle.Buttons}`]: {
                display: "flex",
            },
            // [`${Message}`]: {
            //   backgroundColor: theme.colors.messageHover,
            // },
        },
    });
})(MessageContainerStyle = exports.MessageContainerStyle || (exports.MessageContainerStyle = {}));
exports.ReplyInfo = stitches_config_1.styled.withConfig({
    displayName: "reply-info",
    componentId: stitches_config_1.commonComponentId,
})("div", {
    display: "flex",
    flexDirection: "row",
    marginBottom: stitches_config_1.theme.space.small,
});
exports.ReplyUser = stitches_config_1.styled.withConfig({
    displayName: "reply-user",
    componentId: stitches_config_1.commonComponentId,
})("span", {
    display: "flex",
    alignItems: "center",
});
const replySpineHeight = 12;
const replySpineTop = 11;
exports.ReplySpine = stitches_config_1.styled.withConfig({
    displayName: "reply-spine",
    componentId: stitches_config_1.commonComponentId,
})("div", {
    position: "absolute",
    height: replySpineHeight,
    top: replySpineTop,
    width: `calc(${stitches_config_1.theme.sizes.messageLeftPadding} / 2 - ${stitches_config_1.theme.space.small})`,
    left: `calc(${stitches_config_1.theme.sizes.messageLeftPadding} / 2 - ${stitches_config_1.theme.borderWidths.spines} / 2)`,
    borderLeft: `${stitches_config_1.theme.borderWidths.spines} solid ${stitches_config_1.theme.colors.spines}`,
    borderTop: `${stitches_config_1.theme.borderWidths.spines} solid ${stitches_config_1.theme.colors.spines}`,
    borderTopLeftRadius: 6,
});
exports.ThreadSpine = stitches_config_1.styled.withConfig({
    displayName: "thread-spine",
})("div", {
    position: "absolute",
    width: `calc(${stitches_config_1.theme.sizes.messageLeftPadding} / 2 - ${stitches_config_1.theme.space.small})`,
    left: `calc(${stitches_config_1.theme.sizes.messageLeftPadding} / 2 - ${stitches_config_1.theme.borderWidths.spines} / 2)`,
    borderLeft: "2px solid #4f545c",
    borderBottom: "2px solid #4f545c",
    borderBottomLeftRadius: 6,
    top: 48,
    bottom: `calc((${stitches_config_1.theme.sizes.threadButton} + ${stitches_config_1.theme.space.small} + ${stitches_config_1.theme.space.medium}) / 2)`,
    variants: {
        fromThreadCreatedType: {
            // todo: test
            true: {
                top: `calc(${stitches_config_1.theme.sizes.messageTypeIcon} + 10px)`,
                bottom: `calc(${stitches_config_1.theme.sizes.threadButton} / 2)`,
            },
        },
        hasReply: {
            true: {
                top: `calc(48px + ${replySpineHeight + replySpineTop}px + ${stitches_config_1.theme.space.xs})`,
            },
        },
    },
});
exports.MiniUserAvatar = stitches_config_1.styled.withConfig({
    displayName: "mini-user-avatar",
    componentId: stitches_config_1.commonComponentId,
})("img", {
    borderRadius: "100%",
    width: 16,
    height: 16,
});
exports.MiniUserName = stitches_config_1.styled.withConfig({
    displayName: "mini-user-name",
    componentId: stitches_config_1.commonComponentId,
})("span", {
    marginLeft: stitches_config_1.theme.space.small,
    marginRight: stitches_config_1.theme.space.small,
    fontSize: stitches_config_1.theme.fontSizes.m,
    opacity: 0.64,
    fontWeight: 500,
    whiteSpace: "nowrap",
    overflow: "hidden",
    maxWidth: "25vw",
    textOverflow: "ellipsis",
    color: stitches_config_1.theme.colors.primaryOpacity100
});
exports.SystemMessage = stitches_config_1.styled.withConfig({
    displayName: "system-message",
    componentId: stitches_config_1.commonComponentId,
})(exports.Message, {
    display: "flex",
    flexWrap: "wrap",
    alignItems: "center",
});
exports.SystemMessageIconSize = 18;
exports.SystemMessageIcon = stitches_config_1.styled.withConfig({
    displayName: "system-message-icon",
    componentId: stitches_config_1.commonComponentId,
})(SvgFromUrl_1.default, {
    position: "absolute",
    top: "50%",
    left: `calc(${stitches_config_1.theme.sizes.messageLeftPadding} / 2)`,
    translate: "-50% -50%",
});
exports.ThreadCreatedIcon = stitches_config_1.styled.withConfig({
    displayName: "thread-created-icon",
    componentId: stitches_config_1.commonComponentId,
})(SvgFromUrl_1.default, {
    position: "absolute",
    left: `calc(${stitches_config_1.theme.sizes.messageLeftPadding} / 2)`,
    marginTop: stitches_config_1.theme.space.medium,
    top: 0,
    translate: "-50% 0",
});
exports.SystemMessageContent = stitches_config_1.styled.withConfig({
    displayName: "system-message-content",
    componentId: stitches_config_1.commonComponentId,
})("span", {
    color: stitches_config_1.theme.colors.systemMessageDark,
    variants: {
        fullColor: {
            true: {
                color: stitches_config_1.theme.colors.primaryOpacity100,
            },
        },
    },
});
// todo: once we allow library user to specify onClicks, we should based on whether one is set set the cursor to not-allowed (if there is no onClick)
exports.SystemMessageLink = stitches_config_1.styled.withConfig({
    displayName: "system-message-link",
    componentId: stitches_config_1.commonComponentId,
})("span", {
    color: stitches_config_1.theme.colors.primaryOpacity100,
    "&:hover": {
        cursor: "pointer",
        textDecoration: "underline",
    },
});
exports.SlashCommand = stitches_config_1.styled.withConfig({
    displayName: "slash-command",
    componentId: stitches_config_1.commonComponentId,
})("span", {
    color: stitches_config_1.theme.colors.primaryOpacity60,
    fontSize: stitches_config_1.theme.fontSizes.m,
    userSelect: "none",
});
exports.UnknownReply = stitches_config_1.styled.withConfig({
    displayName: "unknown-reply",
    componentId: stitches_config_1.commonComponentId,
})("span", {
    color: stitches_config_1.theme.colors.primaryOpacity60,
    fontSize: stitches_config_1.theme.fontSizes.m,
    userSelect: "none",
    fontStyle: "italic",
});
exports.UnknownReplyIcon = stitches_config_1.styled.withConfig({
    displayName: "unknown-reply-icon",
    componentId: stitches_config_1.commonComponentId,
})(SvgFromUrl_1.default, {
    backgroundColor: stitches_config_1.theme.colors.backgroundTertiary,
    borderRadius: "50%",
    marginRight: stitches_config_1.theme.space.small,
    padding: 4, // 16 - size of svg (12), aka do not tie up to theme
});
exports.SlashCommandText = stitches_config_1.styled.withConfig({
    displayName: "slash-command-text",
    componentId: stitches_config_1.commonComponentId,
})("span", {
    color: stitches_config_1.theme.colors.link,
});
exports.RoleIcon = stitches_config_1.styled.withConfig({
    displayName: "role-icon",
    componentId: stitches_config_1.commonComponentId,
})("img", {
    marginLeft: stitches_config_1.theme.space.small,
    width: 20,
    height: 20,
});
//# sourceMappingURL=message.js.map