"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Timestamp = void 0;
const moment_1 = __importDefault(require("moment"));
const Tooltip_1 = __importDefault(require("../../../Tooltip"));
const react_1 = __importDefault(require("react"));
const stitches_config_1 = require("../../../Stitches/stitches.config");
var TimestampStyle;
(function (TimestampStyle) {
    TimestampStyle["ShortTime"] = "t";
    TimestampStyle["LongTime"] = "T";
    TimestampStyle["ShortDate"] = "d";
    TimestampStyle["LongDate"] = "D";
    TimestampStyle["ShortDateTime"] = "f";
    TimestampStyle["LongDateTime"] = "F";
    TimestampStyle["RelativeTime"] = "R";
})(TimestampStyle || (TimestampStyle = {}));
function Timestamp({ data: { timestamp, style } }) {
    const time = (0, moment_1.default)(parseInt(timestamp) * 1000);
    // https://momentjs.com/docs/#/displaying/format/
    const formats = {
        t: "LT",
        T: "LTS",
        d: "L",
        D: "LL",
        f: "LLL",
        F: "LLLL",
    };
    function displayTime(style) {
        return time.format(formats[style]);
    }
    return (react_1.default.createElement(Tooltip_1.default, { mouseEnterDelay: 0.1, placement: "top", overlay: displayTime(TimestampStyle.LongDateTime) },
        react_1.default.createElement(TSSpan, null, style === TimestampStyle.RelativeTime
            ? time.fromNow()
            : displayTime(style !== null && style !== void 0 ? style : TimestampStyle.ShortDateTime))));
}
exports.Timestamp = Timestamp;
const TSSpan = stitches_config_1.styled.withConfig({
    displayName: "timestamp-span",
    componentId: stitches_config_1.commonComponentId,
})("span", (0, stitches_config_1.css)({
    backgroundColor: stitches_config_1.theme.colors.primaryOpacity10,
    borderRadius: 3,
    padding: `0 ${stitches_config_1.theme.space.xs}`,
}));
//# sourceMappingURL=Timestamp.js.map